@@ -26,5 +26,5 @@
 void _gnutls_print_state(gnutls_session_t session);
 #endif
 const char *_gnutls_packet2str(content_type_t packet);
-const char *_gnutls_handshake2str(handshake_t handshake);
+const char *_gnutls_handshake2str(gnutls_handshake_description_t handshake);
 void _gnutls_dump_mpi(const char *prefix, mpi_t a);
