@@ -42,7 +42,7 @@ typedef mac_hd_t GNUTLS_HASH_HANDLE;
 #define GNUTLS_MAC_FAILED NULL
 
 mac_hd_t _gnutls_hmac_init(gnutls_mac_algorithm_t algorithm,
-			   const void *key, int keylen);
+    const void *key, int keylen);
 #define _gnutls_hmac_get_algo_len _gnutls_hash_get_algo_len
 #define _gnutls_hmac _gnutls_hash
 void _gnutls_hmac_deinit(mac_hd_t handle, void *digest);
@@ -54,17 +54,16 @@ void _gnutls_mac_deinit_ssl3(mac_hd_t handle, void *digest);
 GNUTLS_HASH_HANDLE _gnutls_hash_init(gnutls_mac_algorithm_t algorithm);
 int _gnutls_hash_get_algo_len(gnutls_mac_algorithm_t algorithm);
 int _gnutls_hash(GNUTLS_HASH_HANDLE handle, const void *text,
-		 size_t textlen);
+    size_t textlen);
 void _gnutls_hash_deinit(GNUTLS_HASH_HANDLE handle, void *digest);
 
 int _gnutls_ssl3_generate_random(void *secret, int secret_len,
-				 void *random, int random_len, int bytes,
-				 opaque * ret);
+    void *rnd, int random_len, int bytes, opaque * ret);
 int _gnutls_ssl3_hash_md5(void *first, int first_len, void *second,
-			  int second_len, int ret_len, opaque * ret);
+    int second_len, int ret_len, opaque * ret);
 
 void _gnutls_mac_deinit_ssl3_handshake(mac_hd_t handle, void *digest,
-				       opaque * key, uint32 key_size);
+    opaque * key, uint32 key_size);
 
 GNUTLS_HASH_HANDLE _gnutls_hash_copy(GNUTLS_HASH_HANDLE handle);
 
