@@ -55,20 +55,7 @@ typedef void svoid;		/* for functions that allocate using gnutls_secure_malloc *
 # endif
 #endif				/* HAVE_ALLOCA */
 
-typedef void *(*gnutls_alloc_function) (size_t);
-typedef int (*gnutls_is_secure_function) (const void *);
-typedef void (*gnutls_free_function) (void *);
-typedef void *(*gnutls_realloc_function) (void *, size_t);
-
-extern gnutls_alloc_function gnutls_secure_malloc;
-extern gnutls_alloc_function gnutls_malloc;
-extern gnutls_free_function gnutls_free;
-
 extern int (*_gnutls_is_secure_memory) (const void *);
-extern gnutls_realloc_function gnutls_realloc;
-
-extern void *(*gnutls_calloc) (size_t, size_t);
-extern char *(*gnutls_strdup) (const char *);
 
 /* this realloc function will return ptr if size==0, and
  * will free the ptr if the new allocation failed.
@@ -76,8 +63,8 @@ extern char *(*gnutls_strdup) (const char *);
 void *gnutls_realloc_fast(void *ptr, size_t size);
 
 svoid *gnutls_secure_calloc(size_t nmemb, size_t size);
-void *_gnutls_calloc(size_t nmemb, size_t size);
 
+void *_gnutls_calloc(size_t nmemb, size_t size);
 char *_gnutls_strdup(const char *);
 
 #endif				/* GNUTLS_MEM_H */
