@@ -43,7 +43,6 @@
 #include "gnutls_datum.h"
 #include "ext_max_record.h"
 #include <gnutls_state.h>
-#include <gnutls_alert.h>
 #include <gnutls_dh.h>
 
 /**
@@ -254,12 +253,12 @@ inline static int session_is_valid(gnutls_session_t session)
  * version must have 2 bytes at least.
  */
 inline static
-void copy_record_version(gnutls_session_t session, handshake_t htype,
+void copy_record_version(gnutls_session_t session, gnutls_handshake_description_t htype,
 			 opaque version[2])
 {
     gnutls_protocol_t lver;
 
-    if (htype != GNUTLS_CLIENT_HELLO
+    if (htype != GNUTLS_HANDSHAKE_CLIENT_HELLO
 	|| session->internals.default_record_version[0] == 0) {
 	lver = gnutls_protocol_get_version(session);
 
@@ -286,7 +285,7 @@ void copy_record_version(gnutls_session_t session, handshake_t htype,
  *
  */
 ssize_t _gnutls_send_int(gnutls_session_t session, content_type_t type,
-			 handshake_t htype, const void *_data,
+			 gnutls_handshake_description_t htype, const void *_data,
 			 size_t sizeofdata)
 {
     uint8 *cipher;
@@ -494,7 +493,7 @@ static int check_buffers(gnutls_session_t session, content_type_t type,
  */
 static
 int record_check_headers(gnutls_session_t session,
-    uint8 headers[RECORD_HEADER_SIZE], content_type_t type, handshake_t htype,
+    uint8 headers[RECORD_HEADER_SIZE], content_type_t type, gnutls_handshake_description_t htype,
     /*output */ content_type_t * recv_type, opaque version[2], uint16 * length,
     uint16 * header_size)
 {
@@ -503,7 +502,7 @@ int record_check_headers(gnutls_session_t session,
      * version 2 message 
      */
 
-    if (htype == GNUTLS_CLIENT_HELLO && type == GNUTLS_HANDSHAKE
+    if (htype == GNUTLS_HANDSHAKE_CLIENT_HELLO && type == GNUTLS_HANDSHAKE
 	&& headers[0] > 127) {
 
 	/* if msb set and expecting handshake message
@@ -547,9 +546,9 @@ int record_check_headers(gnutls_session_t session,
  */
 inline
     static int record_check_version(gnutls_session_t session,
-				    handshake_t htype, opaque version[2])
+				    gnutls_handshake_description_t htype, opaque version[2])
 {
-    if (htype == GNUTLS_CLIENT_HELLO) {
+    if (htype == GNUTLS_HANDSHAKE_CLIENT_HELLO) {
 	/* Reject hello packets with major version higher than 3.
 	 */
 	if (version[0] > 3) {
@@ -559,7 +558,7 @@ inline
 		 htype, version[0], version[1]);
 	    return GNUTLS_E_UNSUPPORTED_VERSION_PACKET;
 	}
-    } else if (htype != GNUTLS_SERVER_HELLO &&
+    } else if (htype != GNUTLS_HANDSHAKE_SERVER_HELLO &&
 	       gnutls_protocol_get_version(session) !=
 	       _gnutls_version_get(version[0], version[1])) {
 	/* Reject record packets that have a different version than the
@@ -581,7 +580,7 @@ inline
  */
 static int record_check_type(gnutls_session_t session,
     content_type_t recv_type, content_type_t type,
-    handshake_t htype, opaque * data, int data_size)
+    gnutls_handshake_description_t htype, opaque * data, int data_size)
 {
 
     int ret;
@@ -648,7 +647,7 @@ static int record_check_type(gnutls_session_t session,
 	     * if expecting client hello (for rehandshake
 	     * reasons). Otherwise it is an unexpected packet
 	     */
-	    if (type==GNUTLS_ALERT || (htype == GNUTLS_CLIENT_HELLO
+	    if (type==GNUTLS_ALERT || (htype == GNUTLS_HANDSHAKE_CLIENT_HELLO
 		&& type == GNUTLS_HANDSHAKE))
 		return GNUTLS_E_GOT_APPLICATION_DATA;
 	    else {
@@ -736,10 +735,10 @@ inline
  * receive (if called by the user the Content is Userdata only)
  * It is intended to receive data, under the current session.
  *
- * The handshake_t was introduced to support SSL V2.0 client hellos.
+ * The gnutls_handshake_description_t was introduced to support SSL V2.0 client hellos.
  */
 ssize_t _gnutls_recv_int(gnutls_session_t session, content_type_t type,
-			 handshake_t htype, opaque * data,
+			 gnutls_handshake_description_t htype, opaque * data,
 			 size_t sizeofdata)
 {
     gnutls_datum_t tmp;
@@ -983,16 +982,6 @@ ssize_t _gnutls_recv_int(gnutls_session_t session, content_type_t type,
   * difference is that is accepts a GNUTLS session, and uses different
   * error codes.
   *
-  * In the special case that a server requests a renegotiation, the
-  * client may receive an error code of %GNUTLS_E_REHANDSHAKE.  This
-  * message may be simply ignored, replied with an alert containing
-  * %GNUTLS_A_NO_RENEGOTIATION, or replied with a new handshake,
-  * depending on the client's will.
-  *
-  * A server may also receive %GNUTLS_E_REHANDSHAKE when a client has
-  * initiated a handshake. In that case the server can only initiate a
-  * handshake or terminate the connection.
-  *
   * If the EINTR is returned by the internal push function (the
   * default is send()} then %GNUTLS_E_INTERRUPTED will be returned. If
   * %GNUTLS_E_INTERRUPTED or %GNUTLS_E_AGAIN is returned, you must
