@@ -71,6 +71,8 @@ typedef struct gnutls_x509_privkey_int {
      *      [3] is prime1 (p)
      *      [4] is prime2 (q)
      *      [5] is coefficient (u == inverse of p mod q)
+     *          note that other packages used inverse of q mod p,
+     *          so we need to perform conversions.
      * DSA: [0] is p
      *      [1] is q
      *      [2] is g
@@ -90,98 +92,80 @@ typedef struct gnutls_x509_privkey_int {
 } gnutls_x509_privkey_int;
 
 int gnutls_x509_crt_get_issuer_dn_by_oid(gnutls_x509_crt_t cert,
-					 const char *oid, int indx,
-					 unsigned int raw_flag, void *buf,
-					 size_t * sizeof_buf);
+    const char *oid, int indx, unsigned int raw_flag, void *buf,
+    size_t * sizeof_buf);
 int gnutls_x509_crt_get_subject_alt_name(gnutls_x509_crt_t cert,
-					 unsigned int seq, void *ret,
-					 size_t * ret_size,
-					 unsigned int *critical);
+    unsigned int seq, void *ret, size_t * ret_size,
+    unsigned int *critical);
 int gnutls_x509_crt_get_dn_by_oid(gnutls_x509_crt_t cert, const char *oid,
-				  int indx, unsigned int raw_flag,
-				  void *buf, size_t * sizeof_buf);
+    int indx, unsigned int raw_flag, void *buf, size_t * sizeof_buf);
 int gnutls_x509_crt_get_ca_status(gnutls_x509_crt_t cert,
-				  unsigned int *critical);
+    unsigned int *critical);
 int gnutls_x509_crt_get_pk_algorithm(gnutls_x509_crt_t cert,
-				     unsigned int *bits);
+    unsigned int *bits);
 
 int _gnutls_x509_crt_cpy(gnutls_x509_crt_t dest, gnutls_x509_crt_t src);
 int _gnutls_x509_crt_get_raw_issuer_dn(gnutls_x509_crt_t cert,
-				       gnutls_datum_t * start);
+    gnutls_datum_t * start);
 int _gnutls_x509_crt_get_raw_dn(gnutls_x509_crt_t cert,
-				gnutls_datum_t * start);
+    gnutls_datum_t * start);
 
 int gnutls_x509_crt_get_serial(gnutls_x509_crt_t cert, void *result,
-			       size_t * result_size);
+    size_t * result_size);
 
 int _gnutls_x509_compare_raw_dn(const gnutls_datum_t * dn1,
-				const gnutls_datum_t * dn2);
+    const gnutls_datum_t * dn2);
 
 int gnutls_x509_crt_check_revocation(gnutls_x509_crt_t cert,
-				     const gnutls_x509_crl_t * crl_list,
-				     int crl_list_length);
+    const gnutls_x509_crl_t * crl_list, int crl_list_length);
 
 
 int _gnutls_x509_crl_cpy(gnutls_x509_crl_t dest, gnutls_x509_crl_t src);
 int _gnutls_x509_crl_get_raw_issuer_dn(gnutls_x509_crl_t crl,
-				       gnutls_datum_t * dn);
+    gnutls_datum_t * dn);
 int gnutls_x509_crl_get_crt_count(gnutls_x509_crl_t crl);
 int gnutls_x509_crl_get_crt_serial(gnutls_x509_crl_t crl, int indx,
-				   unsigned char *serial,
-				   size_t * serial_size, time_t * tim);
+    unsigned char *serial, size_t * serial_size, time_t * tim);
 
 void gnutls_x509_crl_deinit(gnutls_x509_crl_t crl);
 int gnutls_x509_crl_init(gnutls_x509_crl_t * crl);
 int gnutls_x509_crl_import(gnutls_x509_crl_t crl,
-			   const gnutls_datum_t * data,
-			   gnutls_x509_crt_fmt_t format);
+    const gnutls_datum_t * data, gnutls_x509_crt_fmt_t format);
 int gnutls_x509_crl_export(gnutls_x509_crl_t crl,
-			   gnutls_x509_crt_fmt_t format, void *output_data,
-			   size_t * output_data_size);
+    gnutls_x509_crt_fmt_t format, void *output_data, 
+    size_t * output_data_size);
 
 int gnutls_x509_crt_init(gnutls_x509_crt_t * cert);
 void gnutls_x509_crt_deinit(gnutls_x509_crt_t cert);
 int gnutls_x509_crt_import(gnutls_x509_crt_t cert,
-			   const gnutls_datum_t * data,
-			   gnutls_x509_crt_fmt_t format);
+    const gnutls_datum_t * data, gnutls_x509_crt_fmt_t format);
 int gnutls_x509_crt_export(gnutls_x509_crt_t cert,
-			   gnutls_x509_crt_fmt_t format, void *output_data,
-			   size_t * output_data_size);
+    gnutls_x509_crt_fmt_t format, void *output_data,
+    size_t * output_data_size);
 
 int gnutls_x509_crt_get_key_usage(gnutls_x509_crt_t cert,
-				  unsigned int *key_usage,
-				  unsigned int *critical);
+    unsigned int *key_usage, unsigned int *critical);
 int gnutls_x509_crt_get_version(gnutls_x509_crt_t cert);
 
 int gnutls_x509_privkey_init(gnutls_x509_privkey_t * key);
 void gnutls_x509_privkey_deinit(gnutls_x509_privkey_t key);
 
 int gnutls_x509_privkey_generate(gnutls_x509_privkey_t key,
-				 gnutls_pk_algorithm_t algo,
-				 unsigned int bits, unsigned int flags);
+    gnutls_pk_algorithm_t algo, unsigned int bits, unsigned int flags);
 
 int gnutls_x509_privkey_import(gnutls_x509_privkey_t key,
-			       const gnutls_datum_t * data,
-			       gnutls_x509_crt_fmt_t format);
+     const gnutls_datum_t * data, gnutls_x509_crt_fmt_t format);
 int gnutls_x509_privkey_get_pk_algorithm(gnutls_x509_privkey_t key);
 int gnutls_x509_privkey_import_rsa_raw(gnutls_x509_privkey_t key,
-				       const gnutls_datum_t * m,
-				       const gnutls_datum_t * e,
-				       const gnutls_datum_t * d,
-				       const gnutls_datum_t * p,
-				       const gnutls_datum_t * q,
-				       const gnutls_datum_t * u);
+    const gnutls_datum_t * m, const gnutls_datum_t * e,
+    const gnutls_datum_t * d, const gnutls_datum_t * p,
+    const gnutls_datum_t * q, const gnutls_datum_t * u);
 int gnutls_x509_privkey_export_rsa_raw(gnutls_x509_privkey_t key,
-				       gnutls_datum_t * m,
-				       gnutls_datum_t * e,
-				       gnutls_datum_t * d,
-				       gnutls_datum_t * p,
-				       gnutls_datum_t * q,
-				       gnutls_datum_t * u);
+    gnutls_datum_t * m, gnutls_datum_t * e, gnutls_datum_t * d,
+    gnutls_datum_t * p, gnutls_datum_t * q, gnutls_datum_t * u);
 int gnutls_x509_privkey_export(gnutls_x509_privkey_t key,
-			       gnutls_x509_crt_fmt_t format,
-			       void *output_data,
-			       size_t * output_data_size);
+    gnutls_x509_crt_fmt_t format, void *output_data,
+    size_t * output_data_size);
 
 #define GNUTLS_CRL_REASON_UNUSED 128
 #define GNUTLS_CRL_REASON_KEY_COMPROMISE 64
