@@ -1,23 +1,25 @@
 /*
- * Copyright (C) 2004 Simon Josefsson
- * Copyright (C) 2001 Nikos Mavroyanopoulos
- * Copyright (C) 2004 Free Software Foundation
+ * Copyright (C) 2001, 2004, 2005 Free Software Foundation
  *
- * This file is part of GNUTLS.
+ * Author: Nikos Mavroyanopoulos
  *
- * GNUTLS-EXTRA is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This file is part of GNUTLS-EXTRA.
  *
- * GNUTLS-EXTRA is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNUTLS-EXTRA is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * GNUTLS-EXTRA is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA
+ *
  */
 
 #include <gnutls_int.h>
@@ -93,7 +95,7 @@ extern OPENPGP_PRIVKEY_DEINIT _E_gnutls_openpgp_privkey_deinit;
 
 static void _gnutls_add_openpgp_functions(void)
 {
-#ifdef USE_OPENPGP
+#ifdef ENABLE_OPENPGP
     _E_gnutls_openpgp_verify_key = _gnutls_openpgp_verify_key;
     _E_gnutls_openpgp_get_raw_key_expiration_time =
 	_gnutls_openpgp_get_raw_key_expiration_time;
