@@ -97,7 +97,7 @@ int cipher_priority[PRI_MAX] =
 };
 int comp_priority[PRI_MAX] = { GNUTLS_COMP_ZLIB, GNUTLS_COMP_NULL, 0 };
 int mac_priority[PRI_MAX] =
-    { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
+    { GNUTLS_MAC_SHA1, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
 int cert_type_priority[PRI_MAX] =
     { GNUTLS_CRT_X509, GNUTLS_CRT_OPENPGP, 0 };
 
@@ -155,7 +155,9 @@ static void munmap_file(gnutls_datum data)
     munmap(data.data, data.size);
 }
 
-static gnutls_x509_crt x509_crt = NULL;
+#define MAX_CRT 6
+static unsigned int x509_crt_size;
+static gnutls_x509_crt x509_crt[MAX_CRT];
 static gnutls_x509_privkey x509_key = NULL;
 
 static gnutls_openpgp_key pgp_crt = NULL;
@@ -165,6 +167,7 @@ static gnutls_openpgp_privkey pgp_key = NULL;
  */
 static void load_keys(void)
 {
+    unsigned int crt_num;
     int ret;
     gnutls_datum data;
 
@@ -174,15 +177,24 @@ static void load_keys(void)
 	    fprintf(stderr, "*** Error loading cert file.\n");
 	    exit(1);
 	}
-	gnutls_x509_crt_init(&x509_crt);
 
-	ret = gnutls_x509_crt_import(x509_crt, &data, GNUTLS_X509_FMT_PEM);
+        crt_num = MAX_CRT;
+	ret = gnutls_x509_crt_list_import(x509_crt, &crt_num, &data, GNUTLS_X509_FMT_PEM, GNUTLS_X509_CRT_LIST_IMPORT_FAIL_IF_EXCEED);
 	if (ret < 0) {
-	    fprintf(stderr,
+	    if (ret==GNUTLS_E_SHORT_MEMORY_BUFFER) {
+	        fprintf(stderr,
+		    "*** Error loading cert file: Too many certs %d\n",
+		    crt_num);
+	    
+	    } else {
+	        fprintf(stderr,
 		    "*** Error loading cert file: %s\n",
 		    gnutls_strerror(ret));
-	    exit(1);
+            }
+            exit(1);
 	}
+	x509_crt_size = ret;
+	/* fprintf(stderr, "Processed %d client certificates...\n", ret); */
 
 	munmap_file(data);
 
@@ -299,9 +311,9 @@ static int cert_callback(gnutls_session session,
 
     if (st->type == GNUTLS_CRT_X509) {
 	if (x509_crt != NULL && x509_key != NULL) {
-	    st->ncerts = 1;
+	    st->ncerts = x509_crt_size;
 
-	    st->cert.x509 = &x509_crt;
+	    st->cert.x509 = x509_crt;
 	    st->key.x509 = x509_key;
 
 	    st->deinit_all = 0;
@@ -901,7 +913,7 @@ static void init_global_tls_stuff(void)
 	exit(1);
     }
 
-    /* there are some intermediate CAs that have a v1 certificate *%&@#*%&
+    /* there are some CAs that have a v1 certificate *%&@#*%&
      */
     gnutls_certificate_set_verify_flags(xcred,
 					GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT);
